@@ -6,7 +6,7 @@
 ;;         Rudolf Schlatte <rudi@constantly.at>
 ;;         Kristoffer Balintona <krisbalintona@gmail.com>
 ;; URL: https://codeberg.org/emacs-jj-vc/vc-jj.el
-;; Version: 0.4
+;; Version: 0.5
 ;; Package-Requires: ((emacs "28.1") (compat "29.4"))
 ;; Keywords: vc tools
 
@@ -25,39 +25,45 @@
 
 ;;; Commentary:
 
-;; A backend for vc.el to handle Jujutsu (jj) repositories.
+;; This package provides a backend for vc.el to handle Jujutsu (jj)
+;; repositories.  Jujutsu uses a change-centric model that differs in
+;; important ways from Git’s commit-centric model.  Vc-jj adapts
+;; vc.el’s abstractions to match jj terminology and behavior.
 ;;
-;; Jujutsu is a distributed version control system that uses the same
-;; on-disk storage format as git (although other storage backends are
-;; possible).  Jj repositories are "co-located" by default, which
-;; means they contain both a '.jj' and a '.git' directory in the
-;; repository root.  Therefore, vc-jj can re-use some functionality of
-;; vc-git, like handling of '.gitignore' files.  It is possible to run
-;; git commands in a co-located repository, although git will complain
-;; about being in "detached HEAD" state.
+;; Users may see and customize all options by pressing
 ;;
-;; Note that 'JJ' should come before 'Git' in `vc-handled-backends' so
-;; that 'vc' chooses the jj backend.
-;;
-;; In jj terminology, vc "revisions" are called "changes" and are
-;; identified by a "change ID"; the code in vc-jj tries to adhere to
-;; this terminology.
-;;
-;; In contrast to git, there is no staging area or check-in operation:
-;; as the user modifies a file, the changes are automatically
-;; recorded.  Note that the change ID stays constant when the current
-;; change is being modified, e.g., by editing a file.  Underlying each
-;; change is a (git-type) commit with a commit ID; the commit ID
-;; changes when a change gets modified.  Most jj commands accept both
-;; change IDs and commit IDs.  We display both change ID and commit ID
-;; where appropriate, for example in the extra headers of vc-dir
-;; buffers.
+;;  'M-x customize-group vc-jj RET'
 ;;
+;; and using the Customize menu.
 
+;; STATUS AND LIMITATIONS
+;;
+;; Vc-jj implements most commonly used vc.el commands (such as
+;; `vc-dir', `vc-diff', `vc-print-log', and file state queries), but
+;; some operations are not yet supported or behave differently from
+;; vc-git due to jj’s model.
+
+;; FILE STRUCTURE
+;;
 ;; After the "Customization" and "Internal Utilities" sections, the
 ;; organization of this file follows the "BACKEND PROPERTIES" section
-;; at the beginning of 'vc.el', implementing the functions listed
-;; there in the same order.
+;; of the preamble of the 'vc.el' file: each outline heading
+;; corresponding to a vc backend method and the contents of each
+;; heading relate to implementing that backend method.
+
+;; FEEDBACK AND CONTRIBUTIONS
+;;
+;; Bug reports and contributions are welcome, especially for
+;; unimplemented vc.el backend methods.  The home of this project is
+;; found here: https://codeberg.org/emacs-jj-vc/vc-jj.el.  Users may
+;; file bug reports in the "Issues" tab and create pull requests in
+;; the "Pull requests" tab.
+;;
+;; Vc-jj prefers jujutsu's terminology and attempts to adhere to it,
+;; so we ask contributors to try their best to use the terminology
+;; specific to jujutsu as opposed to other version control systems,
+;; such as Git.  A brief description of these differences can be found
+;; above.
 
 ;;; Code:
 
@@ -163,7 +169,8 @@ KEYWORDS is a list of font lock keywords (see
 highlighting the Log View buffer.
 
 REGEXP may define capture groups that KEYWORDS can use to fontify
-various regions of the Log View buffer.")
+various regions of the Log View buffer."
+  :type '(list string regexp (repeat sexp)))
 
 (defcustom vc-jj-global-switches '("--no-pager" "--color" "never")
   "Global switches to pass to any jj command."
@@ -175,25 +182,25 @@ various regions of the Log View buffer.")
   "String or list of strings specifying switches for \"jj file annotate\".
 If nil, use the value of `vc-annotate-switches'.  If t, use no switches."
   :type '(choice (const :tag "Unspecified" nil)
-		 (const :tag "None" t)
-		 (string :tag "Argument String")
-		 (repeat :tag "Argument List" :value ("") string)))
+                 (const :tag "None" t)
+                 (string :tag "Argument String")
+                 (repeat :tag "Argument List" :value ("") string)))
 
 (defcustom vc-jj-checkin-switches nil
   "String or list of strings specifying switches for \"jj commit\".
 If nil, use the value of `vc-checkin-switches'.  If t, use no switches."
   :type '(choice (const :tag "Unspecified" nil)
-		 (const :tag "None" t)
-		 (string :tag "Argument String")
-		 (repeat :tag "Argument List" :value ("") string)))
+                 (const :tag "None" t)
+                 (string :tag "Argument String")
+                 (repeat :tag "Argument List" :value ("") string)))
 
 (defcustom vc-jj-diff-switches '("--git")
   "String or list of strings specifying switches for \"jj diff\".
 If nil, use the value of `vc-diff-switches'.  If t, use no switches."
   :type '(choice (const :tag "Unspecified" nil)
-		 (const :tag "None" t)
-		 (string :tag "Argument String")
-		 (repeat :tag "Argument List" :value ("") string)))
+                 (const :tag "None" t)
+                 (string :tag "Argument String")
+                 (repeat :tag "Argument List" :value ("") string)))
 
 (defface vc-jj-log-view-commit
   '((t :weight light :inherit (shadow italic)))
@@ -248,16 +255,16 @@ warnings to stderr even when run with '--quiet'."
                          (list (current-buffer) nil)
                          nil args)))
       (unless (eq status 0)
-	(error "'jj' exited with status %s" status))
+        (error "'jj' exited with status %s" status))
       (goto-char (point-min))
       (let (lines)
-	(while (not (eobp))
-	  (setq lines (cons (buffer-substring-no-properties
-			     (line-beginning-position)
-			     (line-end-position))
-			    lines))
-	  (forward-line 1))
-	(nreverse lines)))))
+        (while (not (eobp))
+          (setq lines (cons (buffer-substring-no-properties
+                             (line-beginning-position)
+                             (line-end-position))
+                            lines))
+          (forward-line 1))
+        (nreverse lines)))))
 
 (defun vc-jj--command-parseable (&rest args)
   "Run jj with ARGS, returning its output as string.
@@ -274,7 +281,7 @@ process status."
                          (list (current-buffer) nil)
                          nil args)))
       (unless (eq status 0)
-	(error "'jj' exited with status %s" status))
+        (error "'jj' exited with status %s" status))
       (buffer-substring-no-properties (point-min) (point-max)))))
 
 (defun vc-jj--command-dispatched (buffer okstatus file-or-list &rest flags)
@@ -537,7 +544,7 @@ parents.map(|c| concat(
   "Return the current change id of the repository containing FILE."
   (when-let* ((default-directory (vc-jj-root file)))
     ;; 'jj log' might print a warning at the start of its output,
-    ;; e.g., "Warning: Refused to snapshot some files".  The output we
+    ;; e.g., "Warning: Refused to snapshot some files."  The output we
     ;; want will be printed afterwards.
     (car (last (vc-jj--process-lines "log" "--no-graph"
                                      "-r" "@"
@@ -651,7 +658,7 @@ If PROMPT is non-nil, prompt for the jj command to run (default is \"jj
 git fetch\")."
   (let* ((command (if prompt
                       (split-string-shell-command
-		       (read-shell-command
+                       (read-shell-command
                         (format "jj git fetch command: ")
                         (concat vc-jj-program " git fetch")
                         'vc-jj-pull-history))
@@ -674,7 +681,7 @@ If PROMPT is non-nil, prompt for the command to run (default is \"jj git
 push\")."
   (let* ((command (if prompt
                       (split-string-shell-command
-		       (read-shell-command
+                       (read-shell-command
                         (format "jj git push command: ")
                         (concat vc-jj-program " git push")
                         'vc-jj-push-history))
@@ -1002,7 +1009,7 @@ delete."
                    (1 'change-log-name)
                    (2 'change-log-email)
                    (3 'change-log-date)))))
-  
+
   (when (boundp 'revert-buffer-restore-functions) ; Emacs 30.1
     (add-hook 'revert-buffer-restore-functions #'vc-jj-log-view-restore-position nil t)))
 
